@@ -12,8 +12,8 @@
 
 #include "abstractindexer.h"
 
-#include <KMime/Message>
 #include <Akonadi/KMime/MessageStatus>
+#include <KMime/Message>
 
 class EmailIndexer : public AbstractIndexer
 {
@@ -23,7 +23,7 @@ public:
      * should be stored
      */
     EmailIndexer(const QString &path, const QString &contactDbPath);
-    ~EmailIndexer();
+    ~EmailIndexer() override;
 
     QStringList mimeTypes() const override;
 
