@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
@@ -8,13 +8,16 @@
 #ifndef INDEXEDITEMS_H
 #define INDEXEDITEMS_H
 
-#include <QObject>
 #include "search_pim_export.h"
 #include <AkonadiCore/Item>
+#include <QObject>
 
-namespace Akonadi {
-namespace Search {
-namespace PIM {
+namespace Akonadi
+{
+namespace Search
+{
+namespace PIM
+{
 class IndexedItemsPrivate;
 
 /** Indexed items. */
